/****************************************************************************
** Meta object code from reading C++ file 'khangman.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../khangman-26.04.0/src/khangman.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'khangman.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KHangManE_t {};
} // unnamed namespace

template <> constexpr inline auto KHangMan::qt_create_metaobjectdata<qt_meta_tag_ZN8KHangManE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KHangMan",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "resolveTimeChanged",
        "",
        "soundEnabledChanged",
        "currentLanguageChanged",
        "currentCategoryChanged",
        "currentWordChanged",
        "currentHintChanged",
        "languagesChanged",
        "categoriesChanged",
        "themesChanged",
        "currentThemeChanged",
        "winCountChanged",
        "lossCountChanged",
        "scoreMultiplyingFactorChanged",
        "netScoreChanged",
        "errorOccured",
        "text",
        "setCurrentLanguage",
        "index",
        "setCurrentCategory",
        "setCurrentTheme",
        "slotDownloadNewStuff",
        "KNSCore::Entry*",
        "entry",
        "readFile",
        "nextWord",
        "setWinCount",
        "count",
        "setLossCount",
        "setScoreMultiplyingFactor",
        "factor",
        "replaceLetters",
        "charString",
        "showHandbook",
        "currentWord",
        "getCurrentHint",
        "alphabet",
        "containsChar",
        "original",
        "isResolved",
        "revealCurrentWord",
        "resolveTime",
        "soundEnabled",
        "currentLanguage",
        "languages",
        "currentCategory",
        "categories",
        "currentTheme",
        "themes",
        "backgroundUrl",
        "QUrl",
        "letterColor",
        "QColor",
        "currentHint",
        "winCount",
        "lossCount",
        "scoreMultiplyingFactor",
        "netScore"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resolveTimeChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'soundEnabledChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentLanguageChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentCategoryChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentWordChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentHintChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'languagesChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'categoriesChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'themesChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentThemeChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'winCountChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lossCountChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scoreMultiplyingFactorChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'netScoreChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'errorOccured'
        QtMocHelpers::SignalData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 },
        }}),
        // Slot 'setCurrentLanguage'
        QtMocHelpers::SlotData<void(int)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'setCurrentCategory'
        QtMocHelpers::SlotData<void(int)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'setCurrentTheme'
        QtMocHelpers::SlotData<void(int)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Slot 'slotDownloadNewStuff'
        QtMocHelpers::SlotData<void(KNSCore::Entry *)>(26, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'readFile'
        QtMocHelpers::SlotData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextWord'
        QtMocHelpers::SlotData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWinCount'
        QtMocHelpers::SlotData<void(int)>(31, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Slot 'setLossCount'
        QtMocHelpers::SlotData<void(int)>(33, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Slot 'setScoreMultiplyingFactor'
        QtMocHelpers::SlotData<void(int)>(34, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
        // Slot 'replaceLetters'
        QtMocHelpers::SlotData<void(const QString &)>(36, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'showHandbook'
        QtMocHelpers::SlotData<void() const>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'currentWord'
        QtMocHelpers::MethodData<QStringList() const>(39, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'getCurrentHint'
        QtMocHelpers::MethodData<QString() const>(40, 6, QMC::AccessPublic, QMetaType::QString),
        // Method 'alphabet'
        QtMocHelpers::MethodData<QStringList() const>(41, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Method 'containsChar'
        QtMocHelpers::MethodData<bool(const QString &) const>(42, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 43 },
        }}),
        // Method 'isResolved'
        QtMocHelpers::MethodData<bool() const>(44, 6, QMC::AccessPublic, QMetaType::Bool),
        // Method 'revealCurrentWord'
        QtMocHelpers::MethodData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'resolveTime'
        QtMocHelpers::PropertyData<int>(46, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'soundEnabled'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'currentLanguage'
        QtMocHelpers::PropertyData<int>(48, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'languages'
        QtMocHelpers::PropertyData<QStringList>(49, QMetaType::QStringList, QMC::DefaultPropertyFlags, 6),
        // property 'currentCategory'
        QtMocHelpers::PropertyData<int>(50, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'categories'
        QtMocHelpers::PropertyData<QStringList>(51, QMetaType::QStringList, QMC::DefaultPropertyFlags, 7),
        // property 'currentTheme'
        QtMocHelpers::PropertyData<int>(52, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'themes'
        QtMocHelpers::PropertyData<QStringList>(53, QMetaType::QStringList, QMC::DefaultPropertyFlags, 8),
        // property 'backgroundUrl'
        QtMocHelpers::PropertyData<QUrl>(54, 0x80000000 | 55, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'letterColor'
        QtMocHelpers::PropertyData<QColor>(56, 0x80000000 | 57, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 9),
        // property 'currentWord'
        QtMocHelpers::PropertyData<QStringList>(39, QMetaType::QStringList, QMC::DefaultPropertyFlags, 4),
        // property 'currentHint'
        QtMocHelpers::PropertyData<QString>(58, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
        // property 'alphabet'
        QtMocHelpers::PropertyData<QStringList>(41, QMetaType::QStringList, QMC::DefaultPropertyFlags, 2),
        // property 'winCount'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'lossCount'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'scoreMultiplyingFactor'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'netScore'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KHangMan, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KHangMan::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KHangManE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KHangManE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KHangManE_t>.metaTypes,
    nullptr
} };

void KHangMan::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KHangMan *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resolveTimeChanged(); break;
        case 1: _t->soundEnabledChanged(); break;
        case 2: _t->currentLanguageChanged(); break;
        case 3: _t->currentCategoryChanged(); break;
        case 4: _t->currentWordChanged(); break;
        case 5: _t->currentHintChanged(); break;
        case 6: _t->languagesChanged(); break;
        case 7: _t->categoriesChanged(); break;
        case 8: _t->themesChanged(); break;
        case 9: _t->currentThemeChanged(); break;
        case 10: _t->winCountChanged(); break;
        case 11: _t->lossCountChanged(); break;
        case 12: _t->scoreMultiplyingFactorChanged(); break;
        case 13: _t->netScoreChanged(); break;
        case 14: _t->errorOccured((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 15: _t->setCurrentLanguage((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->setCurrentCategory((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->setCurrentTheme((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->slotDownloadNewStuff((*reinterpret_cast<std::add_pointer_t<KNSCore::Entry*>>(_a[1]))); break;
        case 19: _t->readFile(); break;
        case 20: _t->nextWord(); break;
        case 21: _t->setWinCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->setLossCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 23: _t->setScoreMultiplyingFactor((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->replaceLetters((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->showHandbook(); break;
        case 26: { QStringList _r = _t->currentWord();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 27: { QString _r = _t->getCurrentHint();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 28: { QStringList _r = _t->alphabet();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->containsChar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->isResolved();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: _t->revealCurrentWord(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::resolveTimeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::soundEnabledChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::currentLanguageChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::currentCategoryChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::currentWordChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::currentHintChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::languagesChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::categoriesChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::themesChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::currentThemeChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::winCountChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::lossCountChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::scoreMultiplyingFactorChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)()>(_a, &KHangMan::netScoreChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KHangMan::*)(const QString & )>(_a, &KHangMan::errorOccured, 14))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->resolveTime(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->soundEnabled(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->currentLanguage(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->languages(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->currentCategory(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->categories(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->currentTheme(); break;
        case 7: *reinterpret_cast<QStringList*>(_v) = _t->themes(); break;
        case 8: *reinterpret_cast<QUrl*>(_v) = _t->backgroundUrl(); break;
        case 9: *reinterpret_cast<QColor*>(_v) = _t->currentThemeLetterColor(); break;
        case 10: *reinterpret_cast<QStringList*>(_v) = _t->currentWord(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->getCurrentHint(); break;
        case 12: *reinterpret_cast<QStringList*>(_v) = _t->alphabet(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->winCount(); break;
        case 14: *reinterpret_cast<int*>(_v) = _t->lossCount(); break;
        case 15: *reinterpret_cast<int*>(_v) = _t->scoreMultiplyingFactor(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->netScore(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setResolveTime(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setSoundEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setCurrentLanguage(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setCurrentCategory(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setCurrentTheme(*reinterpret_cast<int*>(_v)); break;
        case 13: _t->setWinCount(*reinterpret_cast<int*>(_v)); break;
        case 14: _t->setLossCount(*reinterpret_cast<int*>(_v)); break;
        case 15: _t->setScoreMultiplyingFactor(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KHangMan::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KHangMan::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KHangManE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KHangMan::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void KHangMan::resolveTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KHangMan::soundEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KHangMan::currentLanguageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KHangMan::currentCategoryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KHangMan::currentWordChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KHangMan::currentHintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KHangMan::languagesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KHangMan::categoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KHangMan::themesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KHangMan::currentThemeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KHangMan::winCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KHangMan::lossCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KHangMan::scoreMultiplyingFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KHangMan::netScoreChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KHangMan::errorOccured(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1);
}
QT_WARNING_POP
